'''
This script will accept any number of Indigo plugins (the bundle) and will clean out stuff
that's not needed, like .pyc files, and then create a zip file that can be attached to
a GitHub release.
'''
import os
import argparse
import fnmatch
import shutil

class indigo_plugin(argparse.Action):
    def __call__(self, parser, namespace, values, option_string=None):
        validated_paths = []
        for  prospective_dir in values:
            if not os.path.isdir(prospective_dir):
                raise argparse.ArgumentError(argument=None, message="'{0}' is not a valid path".format(prospective_dir))
            if not os.access(prospective_dir, os.R_OK):
                raise argparse.ArgumentError(argument=None, message="'{0}' is not a readable dir".format(prospective_dir))
            try:
                file_name, file_extension = os.path.splitext(prospective_dir)
                if file_extension != ".indigoPlugin":
                    raise Exception()
            except:
                raise argparse.ArgumentError(argument=None, message="'{0}' is not an Indigo Plugin Bundle".format(prospective_dir))
            # It passes all checks, so
            validated_paths.append(prospective_dir)
        if len(validated_paths):
            setattr(namespace, self.dest, validated_paths)

def find_files(directory, pattern='*'):
    if not os.path.exists(directory):
        raise ValueError("Directory not found {}".format(directory))

    matches = []
    for root, dirnames, filenames in os.walk(directory):
        for filename in filenames:
            full_path = os.path.join(root, filename)
            if fnmatch.filter([full_path], pattern):
                matches.append(os.path.join(root, filename))
    return matches


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument(
        'plugins', 
        nargs='+', 
        action=indigo_plugin,
        help="Specify at least one Indigo plugin bundle"
    )
    
    args = parser.parse_args()
    for plugin in args.plugins:
        map(os.remove, find_files(plugin, "*.pyc"))
        path, file = os.path.split(plugin)
        shutil.make_archive(plugin, 'zip', base_dir=file, root_dir=path)

if __name__ == "__main__":
   main()
